@@ -4,22 +4,20 @@ Cookiecutter post generation hook script that handles operations after the
 template project is used to generate a target project.
 """
 import os
-import shlex
+import re
 import subprocess
 import sys
 from collections import OrderedDict
+from copy import copy
 from os import path
+from git import Actor, Repo
 
 PROJECT_DIRECTORY = os.path.realpath(os.path.curdir)
 
 def get_request():
-    # Templated Variables should be centralized here for easier inspection
-    COOKIECUTTER = (
-        OrderedDict()
-    )  # We init the variable to the same type that will be set in the next line.
+    # We init the variable to the same type that will be set in the next line.
+    COOKIECUTTER = OrderedDict()
     COOKIECUTTER = {{ cookiecutter }}  # pylint: disable=undefined-variable
-    AUTHOR = "{{ cookiecutter.author }}"
-    AUTHOR_EMAIL = "{{ cookiecutter.author_email }}"
     INITIALIZE_GIT_REPO_FLAG = "{{ cookiecutter.initialize_git_repo|lower }}"
     add_cli_flag = "{{ cookiecutter.add_cli|lower }}"
 
@@ -27,124 +25,16 @@ def get_request():
         'cookiecutter': COOKIECUTTER,
         'project_dir': PROJECT_DIRECTORY,
         'module_name': COOKIECUTTER['pkg_name'],
-        'author': AUTHOR,
-        'author_email': AUTHOR_EMAIL,
+        'author': "{{ cookiecutter.author }}",
+        'author_email': "{{ cookiecutter.author_email }}",
         'initialize_git_repo': {'yes': True}.get(INITIALIZE_GIT_REPO_FLAG, False),
         'add_cli': {'yes': True}.get(add_cli_flag, False),
+        'repo': None,
     })
 
     return request
 
 
-def initialize_git_repo(project_dir: str):
-    """
-    Initialize the Git repository in the generated project.
-    """
-    subprocess.check_output("git init", stderr=subprocess.STDOUT, shell=True, cwd=project_dir)
-
-
-def grant_basic_permissions(project_dir: str):
-    try:
-        subprocess.check_output(
-            f"git config --global --add safe.directory {project_dir}",
-            stderr=subprocess.STDOUT,
-            shell=True,
-            cwd=project_dir,
-        )
-    except Exception:
-        print('WARNING')
-
-
-def git_add(project_dir: str):
-    """
-    Do a Git add operation on the generated project.
-    """
-    subprocess.check_output(
-        "git add --all", stderr=subprocess.STDOUT, shell=True, cwd=project_dir
-    )
-
-
-def git_commit(request):
-    """Commit the staged changes in the generated project."""
-    cookiecutter_config_str = (
-        '\n'.join((f"  {key}: {val}" for key, val in request.cookiecutter.items())) + '\n'
-    )
-    commit_message = (
-        "Template applied from"
-        " https://github.com/boromir674/cookiecutter-python-"
-        "package\n\n"
-        "Template configuration:\n"
-        f"{cookiecutter_config_str}"
-    )
-
-    env = os.environ.copy()
-    env["GIT_COMMITTER_NAME"] = request.author
-    env["GIT_COMMITTER_EMAIL"] = request.author_email
-
-    request.author_info = f'{request.author} <{request.author_email}>'
-    try:
-        subprocess.check_output(
-            (f'git commit --author "{request.author_info}"' f' --message "{commit_message}"'),
-            shell=True,
-            cwd=request.project_dir,
-            env=env,
-        )
-
-    except subprocess.CalledProcessError as exc_info:
-        if exc_info.returncode != 0:
-            print(exc_info.output)
-        raise
-
-
-def python37_n_above_run_params(project_directory: str):
-    return [shlex.split("git status --porcelain")], dict(
-        capture_output=True,
-        cwd=project_directory,
-        check=True,
-    )
-
-
-def python36_n_below_run_params(project_directory: str):
-    return (shlex.split("git status --porcelain"),), dict(
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
-        cwd=project_directory,
-        check=True,
-    )
-
-
-def _get_run_parameters(python3_minor: int):
-    def run(args: list, kwargs: dict):
-        return subprocess.run(*args, **kwargs)
-
-    return {
-        'legacy': lambda project_dir: run(*python36_n_below_run_params(project_dir)),
-        'new': lambda project_dir: run(*python37_n_above_run_params(project_dir)),
-    }[
-        {True: 'legacy', False: 'new'}[
-            python3_minor < 7  # is legacy Python 3.x version (ie 3.5 or 3.6) ?
-        ]
-    ]
-
-
-def is_git_repo_clean(project_directory: str):
-    """
-    Check to confirm if the Git repository is clean and has no uncommitted
-    changes. If its clean return True otherwise False.
-    """
-
-    try:
-        git_status = _get_run_parameters(sys.version_info.minor)(project_directory)
-    except subprocess.CalledProcessError as error:
-        print(f"** Git repository in {project_directory} cannot get status")
-        print('Exception: ' + str(error))
-        raise error
-
-    if git_status.stdout == b"" and git_status.stderr == b"":
-        return True
-
-    return False
-
 class PostFileRemovalError(Exception):
     pass
 
@@ -159,21 +49,117 @@ def post_file_removal(request):
         os.remove(file)
 
 
+def _get_run_parameters(python3_minor: int):
+    def run(args: list, kwargs: dict):
+        return subprocess.run(*args, **dict(kwargs, check=True)) # pylint: disable=W1510 #nosec
+    def _subprocess_run(get_params):
+        def run1(*args, **kwargs):
+            return run(*get_params(*args, **kwargs))
+        return run1
+
+    return {
+        'legacy': _subprocess_run(run_process_python36_n_below),
+        'new': _subprocess_run(run_process_python37_n_above),
+    }[
+        {True: 'legacy', False: 'new'}[
+            python3_minor < 7  # is legacy Python 3.x version (ie 3.5 or 3.6) ?
+        ]
+    ]
+
+
+def run_process_python37_n_above(*args, **kwargs):
+    return [args], dict(capture_output=True, check=True, **kwargs)
+
+def run_process_python36_n_below(*args, **kwargs):
+    return [args], dict(stdout=subprocess.PIPE, stderr=subprocess.PIPE, check=True, **kwargs)
+
+
+def subprocess_run(*args, **kwargs):
+    return _get_run_parameters(sys.version_info.minor)(*args, **kwargs)
+
+
+def initialize_git_repo(project_dir: str):
+    """
+    Initialize the Git repository in the generated project.
+    """
+    subprocess_run('git', 'init', cwd=project_dir)
+
+
+def exception(subprocess_exception: subprocess.CalledProcessError):
+    error_message = str(subprocess_exception.stderr, encoding='utf-8')
+    if re.match(r'error: could not lock config file .+\.gitconfig File exists',
+        error_message):
+        return type('LockFileError', (Exception,), {})(error_message)
+    return subprocess_exception
+
+def grant_basic_permissions(project_dir: str):
+    try:
+        return subprocess_run(
+            'git', 'config', '--global', '--add', 'safe.directory', project_dir,
+            cwd=project_dir,
+        )
+    except subprocess.CalledProcessError as error:
+        print('Did not add an entry in ~/.gitconfig!')
+        print(str(error.stderr, encoding='utf-8'))
+        print(exception(error))
+
+
+def git_commit(request):
+    """Commit the staged changes in the generated project."""
+    cookiecutter_config_str = (
+        '\n'.join((f"  {key}: {val}" for key, val in request.cookiecutter.items())) + '\n'
+    )
+    commit_message = (
+        "Template applied from"
+        " https://github.com/boromir674/cookiecutter-python-"
+        "package\n\n"
+        "Template configuration:\n"
+        f"{cookiecutter_config_str}"
+    )
+    request.repo.index.add(os.listdir(request.project_dir))
+    author = Actor(request.author, request.author_email)
+
+    request.repo.index.commit(
+        commit_message,
+        author=author,
+        committer=copy(author)
+    )
+
+
+def is_git_repo_clean(project_directory: str):
+    """
+    Check to confirm if the Git repository is clean and has no uncommitted
+    changes. If its clean return True otherwise False.
+    """
+    try:
+        git_status = subprocess_run('git', 'status', '--porcelain', cwd=project_directory)
+    except subprocess.CalledProcessError as error:
+        print(f"** Git repository in {project_directory} cannot get status")
+        print('Exception: ' + str(error))
+        raise error
+
+    if git_status.stdout == b"" and git_status.stderr == b"":
+        return True
+
+    return False
+
+
 def _post_hook():
     print('\n --- POST GEN SCRIPT')
     request = get_request()
-    print('Computed Templated Vars for Post Script')
     post_file_removal(request)
     if request.initialize_git_repo:
         try:
             initialize_git_repo(request.project_dir)
             grant_basic_permissions(request.project_dir)
+            request.repo = Repo(request.project_dir)
             if not is_git_repo_clean(request.project_dir):
-                git_add(request.project_dir)
+            # if request.repo.index.diff(None):  # there are changes not added to index
                 git_commit(request)
+            else:
+                print('Index did not update !!')
         except Exception as error:
-            print(error)
-            print('ERROR in Post Script.\nExiting with 1')
+            print(f"{error}\nERROR in Post Script.\nExiting with 1")
             return 1
     return 0
 
